user

package
v0.0.0-...-1d99369 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldDisplayName holds the string denoting the display_name field in the database.
	FieldDisplayName = "display_name"
	// FieldNameChanges holds the string denoting the name_changes field in the database.
	FieldNameChanges = "name_changes"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldVerified holds the string denoting the verified field in the database.
	FieldVerified = "verified"
	// FieldLocked holds the string denoting the locked field in the database.
	FieldLocked = "locked"
	// FieldLastLogin holds the string denoting the last_login field in the database.
	FieldLastLogin = "last_login"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeAmazonShares holds the string denoting the amazon_shares edge name in mutations.
	EdgeAmazonShares = "amazon_shares"
	// EdgeAmazonLists holds the string denoting the amazon_lists edge name in mutations.
	EdgeAmazonLists = "amazon_lists"
	// EdgeDrinks holds the string denoting the drinks edge name in mutations.
	EdgeDrinks = "drinks"
	// EdgeGroceryLists holds the string denoting the grocery_lists edge name in mutations.
	EdgeGroceryLists = "grocery_lists"
	// EdgeGroceryListShares holds the string denoting the grocery_list_shares edge name in mutations.
	EdgeGroceryListShares = "grocery_list_shares"
	// EdgeMovieCollections holds the string denoting the movie_collections edge name in mutations.
	EdgeMovieCollections = "movie_collections"
	// EdgeMovieCollectionShares holds the string denoting the movie_collection_shares edge name in mutations.
	EdgeMovieCollectionShares = "movie_collection_shares"
	// Table holds the table name of the user in the database.
	Table = "users"
	// AmazonSharesTable is the table that holds the amazon_shares relation/edge.
	AmazonSharesTable = "amazon_shares"
	// AmazonSharesInverseTable is the table name for the AmazonShare entity.
	// It exists in this package in order to avoid circular dependency with the "amazonshare" package.
	AmazonSharesInverseTable = "amazon_shares"
	// AmazonSharesColumn is the table column denoting the amazon_shares relation/edge.
	AmazonSharesColumn = "user_amazon_shares"
	// AmazonListsTable is the table that holds the amazon_lists relation/edge. The primary key declared below.
	AmazonListsTable = "user_amazon_lists"
	// AmazonListsInverseTable is the table name for the AmazonList entity.
	// It exists in this package in order to avoid circular dependency with the "amazonlist" package.
	AmazonListsInverseTable = "amazon_lists"
	// DrinksTable is the table that holds the drinks relation/edge.
	DrinksTable = "drinks"
	// DrinksInverseTable is the table name for the Drink entity.
	// It exists in this package in order to avoid circular dependency with the "drink" package.
	DrinksInverseTable = "drinks"
	// DrinksColumn is the table column denoting the drinks relation/edge.
	DrinksColumn = "user_drinks"
	// GroceryListsTable is the table that holds the grocery_lists relation/edge.
	GroceryListsTable = "grocery_lists"
	// GroceryListsInverseTable is the table name for the GroceryList entity.
	// It exists in this package in order to avoid circular dependency with the "grocerylist" package.
	GroceryListsInverseTable = "grocery_lists"
	// GroceryListsColumn is the table column denoting the grocery_lists relation/edge.
	GroceryListsColumn = "user_grocery_lists"
	// GroceryListSharesTable is the table that holds the grocery_list_shares relation/edge.
	GroceryListSharesTable = "grocery_list_shares"
	// GroceryListSharesInverseTable is the table name for the GroceryListShare entity.
	// It exists in this package in order to avoid circular dependency with the "grocerylistshare" package.
	GroceryListSharesInverseTable = "grocery_list_shares"
	// GroceryListSharesColumn is the table column denoting the grocery_list_shares relation/edge.
	GroceryListSharesColumn = "user_grocery_list_shares"
	// MovieCollectionsTable is the table that holds the movie_collections relation/edge.
	MovieCollectionsTable = "movie_collections"
	// MovieCollectionsInverseTable is the table name for the MovieCollection entity.
	// It exists in this package in order to avoid circular dependency with the "moviecollection" package.
	MovieCollectionsInverseTable = "movie_collections"
	// MovieCollectionsColumn is the table column denoting the movie_collections relation/edge.
	MovieCollectionsColumn = "user_movie_collections"
	// MovieCollectionSharesTable is the table that holds the movie_collection_shares relation/edge.
	MovieCollectionSharesTable = "movie_collection_shares"
	// MovieCollectionSharesInverseTable is the table name for the MovieCollectionShare entity.
	// It exists in this package in order to avoid circular dependency with the "moviecollectionshare" package.
	MovieCollectionSharesInverseTable = "movie_collection_shares"
	// MovieCollectionSharesColumn is the table column denoting the movie_collection_shares relation/edge.
	MovieCollectionSharesColumn = "user_movie_collection_shares"
)

Variables

var (
	// DefaultNameChanges holds the default value on creation for the "name_changes" field.
	DefaultNameChanges int8
	// DefaultVerified holds the default value on creation for the "verified" field.
	DefaultVerified bool
	// DefaultLocked holds the default value on creation for the "locked" field.
	DefaultLocked bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)
var (
	// AmazonListsPrimaryKey and AmazonListsColumn2 are the table columns denoting the
	// primary key for the amazon_lists relation (M2M).
	AmazonListsPrimaryKey = []string{"user_id", "amazon_list_id"}
)

Columns holds all SQL columns for user fields.

Functions

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.User

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.User

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.User

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.User

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.User

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.User

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.User

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.User

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.User

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DisplayName

func DisplayName(v string) predicate.User

DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.

func DisplayNameContains

func DisplayNameContains(v string) predicate.User

DisplayNameContains applies the Contains predicate on the "display_name" field.

func DisplayNameContainsFold

func DisplayNameContainsFold(v string) predicate.User

DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.

func DisplayNameEQ

func DisplayNameEQ(v string) predicate.User

DisplayNameEQ applies the EQ predicate on the "display_name" field.

func DisplayNameEqualFold

func DisplayNameEqualFold(v string) predicate.User

DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.

func DisplayNameGT

func DisplayNameGT(v string) predicate.User

DisplayNameGT applies the GT predicate on the "display_name" field.

func DisplayNameGTE

func DisplayNameGTE(v string) predicate.User

DisplayNameGTE applies the GTE predicate on the "display_name" field.

func DisplayNameHasPrefix

func DisplayNameHasPrefix(v string) predicate.User

DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.

func DisplayNameHasSuffix

func DisplayNameHasSuffix(v string) predicate.User

DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.

func DisplayNameIn

func DisplayNameIn(vs ...string) predicate.User

DisplayNameIn applies the In predicate on the "display_name" field.

func DisplayNameLT

func DisplayNameLT(v string) predicate.User

DisplayNameLT applies the LT predicate on the "display_name" field.

func DisplayNameLTE

func DisplayNameLTE(v string) predicate.User

DisplayNameLTE applies the LTE predicate on the "display_name" field.

func DisplayNameNEQ

func DisplayNameNEQ(v string) predicate.User

DisplayNameNEQ applies the NEQ predicate on the "display_name" field.

func DisplayNameNotIn

func DisplayNameNotIn(vs ...string) predicate.User

DisplayNameNotIn applies the NotIn predicate on the "display_name" field.

func Email

func Email(v string) predicate.User

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.User

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.User

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.User

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.User

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.User

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.User

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.User

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.User

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.User

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.User

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.User

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.User

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.User

EmailNotIn applies the NotIn predicate on the "email" field.

func HasAmazonLists

func HasAmazonLists() predicate.User

HasAmazonLists applies the HasEdge predicate on the "amazon_lists" edge.

func HasAmazonListsWith

func HasAmazonListsWith(preds ...predicate.AmazonList) predicate.User

HasAmazonListsWith applies the HasEdge predicate on the "amazon_lists" edge with a given conditions (other predicates).

func HasAmazonShares

func HasAmazonShares() predicate.User

HasAmazonShares applies the HasEdge predicate on the "amazon_shares" edge.

func HasAmazonSharesWith

func HasAmazonSharesWith(preds ...predicate.AmazonShare) predicate.User

HasAmazonSharesWith applies the HasEdge predicate on the "amazon_shares" edge with a given conditions (other predicates).

func HasDrinks

func HasDrinks() predicate.User

HasDrinks applies the HasEdge predicate on the "drinks" edge.

func HasDrinksWith

func HasDrinksWith(preds ...predicate.Drink) predicate.User

HasDrinksWith applies the HasEdge predicate on the "drinks" edge with a given conditions (other predicates).

func HasGroceryListShares

func HasGroceryListShares() predicate.User

HasGroceryListShares applies the HasEdge predicate on the "grocery_list_shares" edge.

func HasGroceryListSharesWith

func HasGroceryListSharesWith(preds ...predicate.GroceryListShare) predicate.User

HasGroceryListSharesWith applies the HasEdge predicate on the "grocery_list_shares" edge with a given conditions (other predicates).

func HasGroceryLists

func HasGroceryLists() predicate.User

HasGroceryLists applies the HasEdge predicate on the "grocery_lists" edge.

func HasGroceryListsWith

func HasGroceryListsWith(preds ...predicate.GroceryList) predicate.User

HasGroceryListsWith applies the HasEdge predicate on the "grocery_lists" edge with a given conditions (other predicates).

func HasMovieCollectionShares

func HasMovieCollectionShares() predicate.User

HasMovieCollectionShares applies the HasEdge predicate on the "movie_collection_shares" edge.

func HasMovieCollectionSharesWith

func HasMovieCollectionSharesWith(preds ...predicate.MovieCollectionShare) predicate.User

HasMovieCollectionSharesWith applies the HasEdge predicate on the "movie_collection_shares" edge with a given conditions (other predicates).

func HasMovieCollections

func HasMovieCollections() predicate.User

HasMovieCollections applies the HasEdge predicate on the "movie_collections" edge.

func HasMovieCollectionsWith

func HasMovieCollectionsWith(preds ...predicate.MovieCollection) predicate.User

HasMovieCollectionsWith applies the HasEdge predicate on the "movie_collections" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func LastLogin

func LastLogin(v time.Time) predicate.User

LastLogin applies equality check predicate on the "last_login" field. It's identical to LastLoginEQ.

func LastLoginEQ

func LastLoginEQ(v time.Time) predicate.User

LastLoginEQ applies the EQ predicate on the "last_login" field.

func LastLoginGT

func LastLoginGT(v time.Time) predicate.User

LastLoginGT applies the GT predicate on the "last_login" field.

func LastLoginGTE

func LastLoginGTE(v time.Time) predicate.User

LastLoginGTE applies the GTE predicate on the "last_login" field.

func LastLoginIn

func LastLoginIn(vs ...time.Time) predicate.User

LastLoginIn applies the In predicate on the "last_login" field.

func LastLoginLT

func LastLoginLT(v time.Time) predicate.User

LastLoginLT applies the LT predicate on the "last_login" field.

func LastLoginLTE

func LastLoginLTE(v time.Time) predicate.User

LastLoginLTE applies the LTE predicate on the "last_login" field.

func LastLoginNEQ

func LastLoginNEQ(v time.Time) predicate.User

LastLoginNEQ applies the NEQ predicate on the "last_login" field.

func LastLoginNotIn

func LastLoginNotIn(vs ...time.Time) predicate.User

LastLoginNotIn applies the NotIn predicate on the "last_login" field.

func Locked

func Locked(v bool) predicate.User

Locked applies equality check predicate on the "locked" field. It's identical to LockedEQ.

func LockedEQ

func LockedEQ(v bool) predicate.User

LockedEQ applies the EQ predicate on the "locked" field.

func LockedNEQ

func LockedNEQ(v bool) predicate.User

LockedNEQ applies the NEQ predicate on the "locked" field.

func NameChanges

func NameChanges(v int8) predicate.User

NameChanges applies equality check predicate on the "name_changes" field. It's identical to NameChangesEQ.

func NameChangesEQ

func NameChangesEQ(v int8) predicate.User

NameChangesEQ applies the EQ predicate on the "name_changes" field.

func NameChangesGT

func NameChangesGT(v int8) predicate.User

NameChangesGT applies the GT predicate on the "name_changes" field.

func NameChangesGTE

func NameChangesGTE(v int8) predicate.User

NameChangesGTE applies the GTE predicate on the "name_changes" field.

func NameChangesIn

func NameChangesIn(vs ...int8) predicate.User

NameChangesIn applies the In predicate on the "name_changes" field.

func NameChangesLT

func NameChangesLT(v int8) predicate.User

NameChangesLT applies the LT predicate on the "name_changes" field.

func NameChangesLTE

func NameChangesLTE(v int8) predicate.User

NameChangesLTE applies the LTE predicate on the "name_changes" field.

func NameChangesNEQ

func NameChangesNEQ(v int8) predicate.User

NameChangesNEQ applies the NEQ predicate on the "name_changes" field.

func NameChangesNotIn

func NameChangesNotIn(vs ...int8) predicate.User

NameChangesNotIn applies the NotIn predicate on the "name_changes" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Verified

func Verified(v bool) predicate.User

Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.

func VerifiedEQ

func VerifiedEQ(v bool) predicate.User

VerifiedEQ applies the EQ predicate on the "verified" field.

func VerifiedNEQ

func VerifiedNEQ(v bool) predicate.User

VerifiedNEQ applies the NEQ predicate on the "verified" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByAmazonLists

func ByAmazonLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAmazonLists orders the results by amazon_lists terms.

func ByAmazonListsCount

func ByAmazonListsCount(opts ...sql.OrderTermOption) OrderOption

ByAmazonListsCount orders the results by amazon_lists count.

func ByAmazonShares

func ByAmazonShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAmazonShares orders the results by amazon_shares terms.

func ByAmazonSharesCount

func ByAmazonSharesCount(opts ...sql.OrderTermOption) OrderOption

ByAmazonSharesCount orders the results by amazon_shares count.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDisplayName

func ByDisplayName(opts ...sql.OrderTermOption) OrderOption

ByDisplayName orders the results by the display_name field.

func ByDrinks

func ByDrinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByDrinks orders the results by drinks terms.

func ByDrinksCount

func ByDrinksCount(opts ...sql.OrderTermOption) OrderOption

ByDrinksCount orders the results by drinks count.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByGroceryListShares

func ByGroceryListShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByGroceryListShares orders the results by grocery_list_shares terms.

func ByGroceryListSharesCount

func ByGroceryListSharesCount(opts ...sql.OrderTermOption) OrderOption

ByGroceryListSharesCount orders the results by grocery_list_shares count.

func ByGroceryLists

func ByGroceryLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByGroceryLists orders the results by grocery_lists terms.

func ByGroceryListsCount

func ByGroceryListsCount(opts ...sql.OrderTermOption) OrderOption

ByGroceryListsCount orders the results by grocery_lists count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastLogin

func ByLastLogin(opts ...sql.OrderTermOption) OrderOption

ByLastLogin orders the results by the last_login field.

func ByLocked

func ByLocked(opts ...sql.OrderTermOption) OrderOption

ByLocked orders the results by the locked field.

func ByMovieCollectionShares

func ByMovieCollectionShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByMovieCollectionShares orders the results by movie_collection_shares terms.

func ByMovieCollectionSharesCount

func ByMovieCollectionSharesCount(opts ...sql.OrderTermOption) OrderOption

ByMovieCollectionSharesCount orders the results by movie_collection_shares count.

func ByMovieCollections

func ByMovieCollections(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByMovieCollections orders the results by movie_collections terms.

func ByMovieCollectionsCount

func ByMovieCollectionsCount(opts ...sql.OrderTermOption) OrderOption

ByMovieCollectionsCount orders the results by movie_collections count.

func ByNameChanges

func ByNameChanges(opts ...sql.OrderTermOption) OrderOption

ByNameChanges orders the results by the name_changes field.

func ByVerified

func ByVerified(opts ...sql.OrderTermOption) OrderOption

ByVerified orders the results by the verified field.

Jump to