Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func DisplayName(v string) predicate.User
- func DisplayNameContains(v string) predicate.User
- func DisplayNameContainsFold(v string) predicate.User
- func DisplayNameEQ(v string) predicate.User
- func DisplayNameEqualFold(v string) predicate.User
- func DisplayNameGT(v string) predicate.User
- func DisplayNameGTE(v string) predicate.User
- func DisplayNameHasPrefix(v string) predicate.User
- func DisplayNameHasSuffix(v string) predicate.User
- func DisplayNameIn(vs ...string) predicate.User
- func DisplayNameLT(v string) predicate.User
- func DisplayNameLTE(v string) predicate.User
- func DisplayNameNEQ(v string) predicate.User
- func DisplayNameNotIn(vs ...string) predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func HasAmazonLists() predicate.User
- func HasAmazonListsWith(preds ...predicate.AmazonList) predicate.User
- func HasAmazonShares() predicate.User
- func HasAmazonSharesWith(preds ...predicate.AmazonShare) predicate.User
- func HasDrinks() predicate.User
- func HasDrinksWith(preds ...predicate.Drink) predicate.User
- func HasGroceryListShares() predicate.User
- func HasGroceryListSharesWith(preds ...predicate.GroceryListShare) predicate.User
- func HasGroceryLists() predicate.User
- func HasGroceryListsWith(preds ...predicate.GroceryList) predicate.User
- func HasMovieCollectionShares() predicate.User
- func HasMovieCollectionSharesWith(preds ...predicate.MovieCollectionShare) predicate.User
- func HasMovieCollections() predicate.User
- func HasMovieCollectionsWith(preds ...predicate.MovieCollection) predicate.User
- func ID(id int) predicate.User
- func IDEQ(id int) predicate.User
- func IDGT(id int) predicate.User
- func IDGTE(id int) predicate.User
- func IDIn(ids ...int) predicate.User
- func IDLT(id int) predicate.User
- func IDLTE(id int) predicate.User
- func IDNEQ(id int) predicate.User
- func IDNotIn(ids ...int) predicate.User
- func LastLogin(v time.Time) predicate.User
- func LastLoginEQ(v time.Time) predicate.User
- func LastLoginGT(v time.Time) predicate.User
- func LastLoginGTE(v time.Time) predicate.User
- func LastLoginIn(vs ...time.Time) predicate.User
- func LastLoginLT(v time.Time) predicate.User
- func LastLoginLTE(v time.Time) predicate.User
- func LastLoginNEQ(v time.Time) predicate.User
- func LastLoginNotIn(vs ...time.Time) predicate.User
- func Locked(v bool) predicate.User
- func LockedEQ(v bool) predicate.User
- func LockedNEQ(v bool) predicate.User
- func NameChanges(v int8) predicate.User
- func NameChangesEQ(v int8) predicate.User
- func NameChangesGT(v int8) predicate.User
- func NameChangesGTE(v int8) predicate.User
- func NameChangesIn(vs ...int8) predicate.User
- func NameChangesLT(v int8) predicate.User
- func NameChangesLTE(v int8) predicate.User
- func NameChangesNEQ(v int8) predicate.User
- func NameChangesNotIn(vs ...int8) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func ValidColumn(column string) bool
- func Verified(v bool) predicate.User
- func VerifiedEQ(v bool) predicate.User
- func VerifiedNEQ(v bool) predicate.User
- type OrderOption
- func ByAmazonLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAmazonListsCount(opts ...sql.OrderTermOption) OrderOption
- func ByAmazonShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAmazonSharesCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
- func ByDrinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByDrinksCount(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByGroceryListShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByGroceryListSharesCount(opts ...sql.OrderTermOption) OrderOption
- func ByGroceryLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByGroceryListsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastLogin(opts ...sql.OrderTermOption) OrderOption
- func ByLocked(opts ...sql.OrderTermOption) OrderOption
- func ByMovieCollectionShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMovieCollectionSharesCount(opts ...sql.OrderTermOption) OrderOption
- func ByMovieCollections(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMovieCollectionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByNameChanges(opts ...sql.OrderTermOption) OrderOption
- func ByVerified(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldDisplayName holds the string denoting the display_name field in the database. FieldDisplayName = "display_name" // FieldNameChanges holds the string denoting the name_changes field in the database. FieldNameChanges = "name_changes" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldVerified holds the string denoting the verified field in the database. FieldVerified = "verified" // FieldLocked holds the string denoting the locked field in the database. FieldLocked = "locked" // FieldLastLogin holds the string denoting the last_login field in the database. FieldLastLogin = "last_login" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" EdgeAmazonShares = "amazon_shares" // EdgeAmazonLists holds the string denoting the amazon_lists edge name in mutations. EdgeAmazonLists = "amazon_lists" // EdgeDrinks holds the string denoting the drinks edge name in mutations. EdgeDrinks = "drinks" // EdgeGroceryLists holds the string denoting the grocery_lists edge name in mutations. EdgeGroceryLists = "grocery_lists" EdgeGroceryListShares = "grocery_list_shares" // EdgeMovieCollections holds the string denoting the movie_collections edge name in mutations. EdgeMovieCollections = "movie_collections" EdgeMovieCollectionShares = "movie_collection_shares" // Table holds the table name of the user in the database. Table = "users" AmazonSharesTable = "amazon_shares" // It exists in this package in order to avoid circular dependency with the "amazonshare" package. AmazonSharesInverseTable = "amazon_shares" AmazonSharesColumn = "user_amazon_shares" // AmazonListsTable is the table that holds the amazon_lists relation/edge. The primary key declared below. AmazonListsTable = "user_amazon_lists" // AmazonListsInverseTable is the table name for the AmazonList entity. // It exists in this package in order to avoid circular dependency with the "amazonlist" package. AmazonListsInverseTable = "amazon_lists" // DrinksTable is the table that holds the drinks relation/edge. DrinksTable = "drinks" // DrinksInverseTable is the table name for the Drink entity. // It exists in this package in order to avoid circular dependency with the "drink" package. DrinksInverseTable = "drinks" // DrinksColumn is the table column denoting the drinks relation/edge. DrinksColumn = "user_drinks" // GroceryListsTable is the table that holds the grocery_lists relation/edge. GroceryListsTable = "grocery_lists" // GroceryListsInverseTable is the table name for the GroceryList entity. // It exists in this package in order to avoid circular dependency with the "grocerylist" package. GroceryListsInverseTable = "grocery_lists" // GroceryListsColumn is the table column denoting the grocery_lists relation/edge. GroceryListsColumn = "user_grocery_lists" GroceryListSharesTable = "grocery_list_shares" // It exists in this package in order to avoid circular dependency with the "grocerylistshare" package. GroceryListSharesInverseTable = "grocery_list_shares" GroceryListSharesColumn = "user_grocery_list_shares" // MovieCollectionsTable is the table that holds the movie_collections relation/edge. MovieCollectionsTable = "movie_collections" // MovieCollectionsInverseTable is the table name for the MovieCollection entity. // It exists in this package in order to avoid circular dependency with the "moviecollection" package. MovieCollectionsInverseTable = "movie_collections" // MovieCollectionsColumn is the table column denoting the movie_collections relation/edge. MovieCollectionsColumn = "user_movie_collections" MovieCollectionSharesTable = "movie_collection_shares" // It exists in this package in order to avoid circular dependency with the "moviecollectionshare" package. MovieCollectionSharesInverseTable = "movie_collection_shares" MovieCollectionSharesColumn = "user_movie_collection_shares" )
Variables ¶
var ( // DefaultNameChanges holds the default value on creation for the "name_changes" field. DefaultNameChanges int8 // DefaultVerified holds the default value on creation for the "verified" field. DefaultVerified bool // DefaultLocked holds the default value on creation for the "locked" field. DefaultLocked bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
var ( // AmazonListsPrimaryKey and AmazonListsColumn2 are the table columns denoting the // primary key for the amazon_lists relation (M2M). AmazonListsPrimaryKey = []string{"user_id", "amazon_list_id"} )
var Columns = []string{ FieldID, FieldDisplayName, FieldNameChanges, FieldEmail, FieldVerified, FieldLocked, FieldLastLogin, FieldCreatedAt, }
Columns holds all SQL columns for user fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DisplayName ¶
DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.
func DisplayNameContains ¶
DisplayNameContains applies the Contains predicate on the "display_name" field.
func DisplayNameContainsFold ¶
DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.
func DisplayNameEQ ¶
DisplayNameEQ applies the EQ predicate on the "display_name" field.
func DisplayNameEqualFold ¶
DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.
func DisplayNameGT ¶
DisplayNameGT applies the GT predicate on the "display_name" field.
func DisplayNameGTE ¶
DisplayNameGTE applies the GTE predicate on the "display_name" field.
func DisplayNameHasPrefix ¶
DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.
func DisplayNameHasSuffix ¶
DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.
func DisplayNameIn ¶
DisplayNameIn applies the In predicate on the "display_name" field.
func DisplayNameLT ¶
DisplayNameLT applies the LT predicate on the "display_name" field.
func DisplayNameLTE ¶
DisplayNameLTE applies the LTE predicate on the "display_name" field.
func DisplayNameNEQ ¶
DisplayNameNEQ applies the NEQ predicate on the "display_name" field.
func DisplayNameNotIn ¶
DisplayNameNotIn applies the NotIn predicate on the "display_name" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func HasAmazonLists ¶
HasAmazonLists applies the HasEdge predicate on the "amazon_lists" edge.
func HasAmazonListsWith ¶
func HasAmazonListsWith(preds ...predicate.AmazonList) predicate.User
HasAmazonListsWith applies the HasEdge predicate on the "amazon_lists" edge with a given conditions (other predicates).
func HasAmazonShares ¶
HasAmazonShares applies the HasEdge predicate on the "amazon_shares" edge.
func HasAmazonSharesWith ¶
func HasAmazonSharesWith(preds ...predicate.AmazonShare) predicate.User
HasAmazonSharesWith applies the HasEdge predicate on the "amazon_shares" edge with a given conditions (other predicates).
func HasDrinksWith ¶
HasDrinksWith applies the HasEdge predicate on the "drinks" edge with a given conditions (other predicates).
func HasGroceryListShares ¶
HasGroceryListShares applies the HasEdge predicate on the "grocery_list_shares" edge.
func HasGroceryListSharesWith ¶
func HasGroceryListSharesWith(preds ...predicate.GroceryListShare) predicate.User
HasGroceryListSharesWith applies the HasEdge predicate on the "grocery_list_shares" edge with a given conditions (other predicates).
func HasGroceryLists ¶
HasGroceryLists applies the HasEdge predicate on the "grocery_lists" edge.
func HasGroceryListsWith ¶
func HasGroceryListsWith(preds ...predicate.GroceryList) predicate.User
HasGroceryListsWith applies the HasEdge predicate on the "grocery_lists" edge with a given conditions (other predicates).
func HasMovieCollectionShares ¶
HasMovieCollectionShares applies the HasEdge predicate on the "movie_collection_shares" edge.
func HasMovieCollectionSharesWith ¶
func HasMovieCollectionSharesWith(preds ...predicate.MovieCollectionShare) predicate.User
HasMovieCollectionSharesWith applies the HasEdge predicate on the "movie_collection_shares" edge with a given conditions (other predicates).
func HasMovieCollections ¶
HasMovieCollections applies the HasEdge predicate on the "movie_collections" edge.
func HasMovieCollectionsWith ¶
func HasMovieCollectionsWith(preds ...predicate.MovieCollection) predicate.User
HasMovieCollectionsWith applies the HasEdge predicate on the "movie_collections" edge with a given conditions (other predicates).
func LastLogin ¶
LastLogin applies equality check predicate on the "last_login" field. It's identical to LastLoginEQ.
func LastLoginEQ ¶
LastLoginEQ applies the EQ predicate on the "last_login" field.
func LastLoginGT ¶
LastLoginGT applies the GT predicate on the "last_login" field.
func LastLoginGTE ¶
LastLoginGTE applies the GTE predicate on the "last_login" field.
func LastLoginIn ¶
LastLoginIn applies the In predicate on the "last_login" field.
func LastLoginLT ¶
LastLoginLT applies the LT predicate on the "last_login" field.
func LastLoginLTE ¶
LastLoginLTE applies the LTE predicate on the "last_login" field.
func LastLoginNEQ ¶
LastLoginNEQ applies the NEQ predicate on the "last_login" field.
func LastLoginNotIn ¶
LastLoginNotIn applies the NotIn predicate on the "last_login" field.
func Locked ¶
Locked applies equality check predicate on the "locked" field. It's identical to LockedEQ.
func NameChanges ¶
NameChanges applies equality check predicate on the "name_changes" field. It's identical to NameChangesEQ.
func NameChangesEQ ¶
NameChangesEQ applies the EQ predicate on the "name_changes" field.
func NameChangesGT ¶
NameChangesGT applies the GT predicate on the "name_changes" field.
func NameChangesGTE ¶
NameChangesGTE applies the GTE predicate on the "name_changes" field.
func NameChangesIn ¶
NameChangesIn applies the In predicate on the "name_changes" field.
func NameChangesLT ¶
NameChangesLT applies the LT predicate on the "name_changes" field.
func NameChangesLTE ¶
NameChangesLTE applies the LTE predicate on the "name_changes" field.
func NameChangesNEQ ¶
NameChangesNEQ applies the NEQ predicate on the "name_changes" field.
func NameChangesNotIn ¶
NameChangesNotIn applies the NotIn predicate on the "name_changes" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Verified ¶
Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.
func VerifiedEQ ¶
VerifiedEQ applies the EQ predicate on the "verified" field.
func VerifiedNEQ ¶
VerifiedNEQ applies the NEQ predicate on the "verified" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByAmazonLists ¶
func ByAmazonLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAmazonLists orders the results by amazon_lists terms.
func ByAmazonListsCount ¶
func ByAmazonListsCount(opts ...sql.OrderTermOption) OrderOption
ByAmazonListsCount orders the results by amazon_lists count.
func ByAmazonShares ¶
func ByAmazonShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAmazonShares orders the results by amazon_shares terms.
func ByAmazonSharesCount ¶
func ByAmazonSharesCount(opts ...sql.OrderTermOption) OrderOption
ByAmazonSharesCount orders the results by amazon_shares count.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDisplayName ¶
func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
ByDisplayName orders the results by the display_name field.
func ByDrinks ¶
func ByDrinks(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByDrinks orders the results by drinks terms.
func ByDrinksCount ¶
func ByDrinksCount(opts ...sql.OrderTermOption) OrderOption
ByDrinksCount orders the results by drinks count.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByGroceryListShares ¶
func ByGroceryListShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByGroceryListShares orders the results by grocery_list_shares terms.
func ByGroceryListSharesCount ¶
func ByGroceryListSharesCount(opts ...sql.OrderTermOption) OrderOption
ByGroceryListSharesCount orders the results by grocery_list_shares count.
func ByGroceryLists ¶
func ByGroceryLists(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByGroceryLists orders the results by grocery_lists terms.
func ByGroceryListsCount ¶
func ByGroceryListsCount(opts ...sql.OrderTermOption) OrderOption
ByGroceryListsCount orders the results by grocery_lists count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastLogin ¶
func ByLastLogin(opts ...sql.OrderTermOption) OrderOption
ByLastLogin orders the results by the last_login field.
func ByLocked ¶
func ByLocked(opts ...sql.OrderTermOption) OrderOption
ByLocked orders the results by the locked field.
func ByMovieCollectionShares ¶
func ByMovieCollectionShares(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMovieCollectionShares orders the results by movie_collection_shares terms.
func ByMovieCollectionSharesCount ¶
func ByMovieCollectionSharesCount(opts ...sql.OrderTermOption) OrderOption
ByMovieCollectionSharesCount orders the results by movie_collection_shares count.
func ByMovieCollections ¶
func ByMovieCollections(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMovieCollections orders the results by movie_collections terms.
func ByMovieCollectionsCount ¶
func ByMovieCollectionsCount(opts ...sql.OrderTermOption) OrderOption
ByMovieCollectionsCount orders the results by movie_collections count.
func ByNameChanges ¶
func ByNameChanges(opts ...sql.OrderTermOption) OrderOption
ByNameChanges orders the results by the name_changes field.
func ByVerified ¶
func ByVerified(opts ...sql.OrderTermOption) OrderOption
ByVerified orders the results by the verified field.